.. _config:

======
config
======

The :class:`CGATReport.Tracker.Config` reads configuration values 
from a cgatreport`ConfigParser` formatted file. These can then be displayed
using the :ref:`table` renderer.

.. report:: Tracker.Config
   :tracks: conf.ini
   :render: table
   
   Table with pipeline parameters.


